pub struct Icon<'a>(_);Expand description
An icon for an Item.
If not provided the icon will default to the workflow icon.
Implementations
sourceimpl<'a> Icon<'a>
impl<'a> Icon<'a>
sourcepub fn with_image(path: impl Into<PathBuf<'a>>) -> Self
pub fn with_image(path: impl Into<PathBuf<'a>>) -> Self
Create a new icon using the image at the given path.
This path can be relative to the workflow directory.
Examples
let icon = Icon::with_image("./assets/icon.png");sourcepub fn with_file_icon(path: impl Into<PathBuf<'a>>) -> Self
pub fn with_file_icon(path: impl Into<PathBuf<'a>>) -> Self
Create a new icon based on the file provided.
This path can be relative to the workflow directory.
Examples
let icon = Icon::with_file_icon("./assets/example.jpg");The above code would use the following icon:
You could combine with “/Applications/Safari.app” to show Safari’s icon:
let icon = Icon::with_file_icon("/Applications/Safari.app");Trait Implementations
impl<'a> Eq for Icon<'a>
impl<'a> StructuralEq for Icon<'a>
impl<'a> StructuralPartialEq for Icon<'a>